@@ -1,6 +1,6 @@
 /* Buffer-oriented functions
 
-   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2008, 2009 Free Software Foundation, Inc.
+   Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2008, 2009, 2010 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -126,21 +126,6 @@ free_buffer (Buffer * bp)
   free (bp);
 }
 
-/*
- * Free all the allocated buffers (used at Zile exit).
- */
-void
-free_buffers (void)
-{
-  Buffer *bp, *next;
-
-  for (bp = head_bp; bp != NULL; bp = next)
-    {
-      next = bp->next;
-      free_buffer (bp);
-    }
-}
-
 /*
  * Initialise a buffer
  */
@@ -341,8 +326,17 @@ calculate_the_region (Region * rp)
       set_region_end (rp, cur_bp->pt);
     }
 
-  set_region_size (rp, point_dist (get_region_start (rp),
-                                   get_region_end (rp)));
+  {
+    Point pt1 = get_region_start (rp), pt2 = get_region_end (rp);
+    int size = -pt1.o + pt2.o;
+    Line *lp;
+
+    for (lp = pt1.p; lp != pt2.p; lp = get_line_next (lp))
+      size += astr_len (get_line_text (lp)) + 1;
+
+    set_region_size (rp, size);
+  }
+
   return true;
 }
 
@@ -481,47 +475,21 @@ tab_width (Buffer * bp)
 /*
  * Copy a region of text into an allocated buffer.
  */
-char *
-copy_text_block (size_t startn, size_t starto, size_t size)
+astr
+copy_text_block (Point pt, size_t size)
 {
-  char *buf, *dp;
-  size_t max_size, n, i;
   Line *lp;
+  astr as = astr_substr (get_line_text (pt.p), pt.o, astr_len (get_line_text (pt.p)) - pt.o);
 
-  max_size = 10;
-  dp = buf = (char *) xzalloc (max_size);
-
-  lp = cur_bp->pt.p;
-  n = cur_bp->pt.n;
-  if (n > startn)
-    do
-      lp = get_line_prev (lp);
-    while (--n > startn);
-  else if (n < startn)
-    do
-      lp = get_line_next (lp);
-    while (++n < startn);
-
-  for (i = starto; dp - buf < (int) size;)
+  astr_cat_char (as, '\n');
+  for (lp = get_line_next (pt.p); astr_len (as) < size; lp = get_line_next (lp))
     {
-      if (dp >= buf + max_size)
-        {
-          int save_off = dp - buf;
-          max_size += 10;
-          buf = (char *) xrealloc (buf, max_size);
-          dp = buf + save_off;
-        }
-      if (i < astr_len (get_line_text (lp)))
-        *dp++ = astr_get (get_line_text (lp), i++);
-      else
-        {
-          *dp++ = '\n';
-          lp = get_line_next (lp);
-          i = 0;
-        }
+      astr_cat (as, get_line_text (lp));
+      astr_cat_char (as, '\n');
     }
+  astr_truncate (as, size);
 
-  return buf;
+  return as;
 }
 
 Buffer *
